part of bwu_polymer_routing.module;

/// Class that can be injected to retrieve information about the current route.
/// For example:
///
///     @Component(/* ... */)
///     class MyComponent implement DetachAware {
///       RouteHandle route;
///
///       MyComponent(RouteProvider routeProvider) {
///         _loadFoo(routeProvider.parameters['fooId']);
///         route = routeProvider.route.newHandle();
///         route.onEnter.listen((RouteEvent e) {
///           // Do something when the route is activated.
///         });
///         route.onLeave.listen((RouteEvent e) {
///           // Do something when the route is de-activated.
///           e.allowLeave(allDataSaved());
///         });
///       }
///
///       detach() {
///         // The route handle must be discarded.
///         route.discard();
///       }
///
///       Future<bool> allDataSaved() {
///         // Check that all data is saved and confirm with the user if needed.
///       }
///     }
///
/// If user component is used outside of ng-view directive then
/// injected [RouteProvider] will be null.
abstract class RouteProvider {
  /// Returns [Route] for current view.
  rt.Route get route;

  /// Returns the name of the current route.
  String get routeName;

  /// Returns parameters for this route.
  Map<String, String> get parameters;
}
